/* this is print stylesheet; stylesheet should print on A4 page*/
body {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-weight: 300;
  color: aquamarine;
  background: darkgreen;
}
h1 {
    font-family: Edwardian Script ITC;
}