body {
  font-family: Edwardian Script ITC, "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-weight: 300;
  color: #000000;
  background: #b6dde8;
  text-align: center;
}

h1
{
    font-family: Edwardian Script ITC;


}

h2 {
    text-align: left;
}

.username {
    font-family: Times New Roman;
    font-size: 22px;
}
.coursename {
    font-family: Times New Roman;
    font-size: 20px;
}

h3 {

}

#content {
    width: 75%;
    /*background: #bc2131;*/
    margin-left: auto;
    margin-right: auto;
}
